==> cscec5b-ecxj-impl-3.0.0-20231122.020216-54-sources.jar: com/ejianc/business/ecxj/bean/CompareEntity.java <==
package com.ejianc.business.ecxj.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 比选报价
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ecxj_compare")
public class CompareEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="notice_id")
    private Long noticeId; // 通知单Id
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_source_id")
    private String projectSourceId; // 项目来源id
    @TableField(value="crop_id")
    private Long cropId; // 项目所属组织id
    @TableField(value="crop_name")
    private String cropName; // 所属公司
    @TableField(value="crop_source_id")
    private String cropSourceId; // 项目所属组织来源id
    @TableField(value="real_corp_id")
    private Long realCorpId; // NC所属组织ID
    @TableField(value="real_nc_corp")
    private String realNcCorp; // NC所属组织PK
    @TableField(value="real_corp_name")
    private String realCorpName; // NC所属组织名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_source_id")
    private String orgSourceId; // 组织来源id
    @TableField(value="org_name")
    private String orgName; // 组织名称

    @TableField(value="material_type_id")
    private Long materialTypeId; // 材料类型Id
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料类型名称

    @TableField(value="submit_deadline")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date submitDeadline; // 填报截止日期
    @TableField(value="compare_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date compareTime; // 比选时间

    @TableField(value="setting_id")
    private Long settingId; // 引用的设置类型Id
    @TableField(value="tender_id")
    private Long tenderId; // 云筑招标Id
    @TableField(value="tender_no")
    private String tenderNo; // 云筑招标编号
    @TableField(value="tender_name")
    private String tenderName; // 云筑招标名称

    @TableField(value="product_type")
    private String productType; // 商品清单类型
    @TableField(value="quote_type")
    private Integer quoteType; // 报价方式
    @TableField(value="compare_status")
    private Integer compareStatus; // 比价状态，0-正常，1-中标，2-流标
    @TableField(value="notification")
    private String notification; // 通知内容
    @TableField(value="create_name")
    private String createName; // 申请人

    @TableField(exist = false)
    @SubEntity(serviceName = "compareSupplierService",pidName = "compareId")
    private List<CompareSupplierEntity> compareSupplierEntities = new ArrayList<>(); // 通知物资清单实体
    @TableField(exist = false)
    @SubEntity(serviceName = "compareSupplierTenderService",pidName = "compareId")
    private List<CompareSupplierTenderEntity> compareSupplierTenderEntities = new ArrayList<>(); // 中标供应商信息



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    public Long getCropId() {
        return cropId;
    }

    public void setCropId(Long cropId) {
        this.cropId = cropId;
    }
    public String getCropName() {
        return cropName;
    }

    public void setCropName(String cropName) {
        this.cropName = cropName;
    }
    public String getCropSourceId() {
        return cropSourceId;
    }

    public void setCropSourceId(String cropSourceId) {
        this.cropSourceId = cropSourceId;
    }
    public Long getRealCorpId() {
        return realCorpId;
    }

    public void setRealCorpId(Long realCorpId) {
        this.realCorpId = realCorpId;
    }
    public String getRealNcCorp() {
        return realNcCorp;
    }

    public void setRealNcCorp(String realNcCorp) {
        this.realNcCorp = realNcCorp;
    }
    public String getRealCorpName() {
        return realCorpName;
    }

    public void setRealCorpName(String realCorpName) {
        this.realCorpName = realCorpName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Date getSubmitDeadline() {
        return submitDeadline;
    }

    public void setSubmitDeadline(Date submitDeadline) {
        this.submitDeadline = submitDeadline;
    }
    public Date getCompareTime() {
        return compareTime;
    }

    public void setCompareTime(Date compareTime) {
        this.compareTime = compareTime;
    }
    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }
    public Long getTenderId() {
        return tenderId;
    }

    public void setTenderId(Long tenderId) {
        this.tenderId = tenderId;
    }
    public String getTenderNo() {
        return tenderNo;
    }

    public void setTenderNo(String tenderNo) {
        this.tenderNo = tenderNo;
    }
    public String getTenderName() {
        return tenderName;
    }

    public void setTenderName(String tenderName) {
        this.tenderName = tenderName;
    }
    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }
    public Integer getQuoteType() {
        return quoteType;
    }

    public void setQuoteType(Integer quoteType) {
        this.quoteType = quoteType;
    }
    public Integer getCompareStatus() {
        return compareStatus;
    }

    public void setCompareStatus(Integer compareStatus) {
        this.compareStatus = compareStatus;
    }
    public String getNotification() {
        return notification;
    }

    public void setNotification(String notification) {
        this.notification = notification;
    }
    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public List<CompareSupplierEntity> getCompareSupplierEntities() {
        return compareSupplierEntities;
    }

    public void setCompareSupplierEntities(List<CompareSupplierEntity> compareSupplierEntities) {
        this.compareSupplierEntities = compareSupplierEntities;
    }

    public List<CompareSupplierTenderEntity> getCompareSupplierTenderEntities() {
        return compareSupplierTenderEntities;
    }

    public void setCompareSupplierTenderEntities(List<CompareSupplierTenderEntity> compareSupplierTenderEntities) {
        this.compareSupplierTenderEntities = compareSupplierTenderEntities;
    }
}

==> cscec5b-ecxj-impl-3.0.0-20241114.031748-106-sources.jar: com/ejianc/business/ecxj/bean/CompareEntity.java <==
package com.ejianc.business.ecxj.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 比选报价
 * 
 * @author generator
 * 
 */
 @TableName("ejc_ecxj_compare")
public class CompareEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="notice_id")
    private Long noticeId; // 通知单Id
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_source_id")
    private String projectSourceId; // 项目来源id
    @TableField(value="crop_id")
    private Long cropId; // 项目所属组织id
    @TableField(value="crop_name")
    private String cropName; // 所属公司
    @TableField(value="crop_source_id")
    private String cropSourceId; // 项目所属组织来源id
    @TableField(value="real_corp_id")
    private Long realCorpId; // NC所属组织ID
    @TableField(value="real_nc_corp")
    private String realNcCorp; // NC所属组织PK
    @TableField(value="real_corp_name")
    private String realCorpName; // NC所属组织名称
    @TableField(value="org_id")
    private Long orgId; // 组织
    @TableField(value="org_source_id")
    private String orgSourceId; // 组织来源id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="wj_linkman")
    private String wjLinkman; // 五局项目联系人
    @TableField(value="wj_linkphone")
    private String wjLinkphone; // 五局项目联系电话

    @TableField(value="is_cooperation")
    private Integer isCooperation; // 是否联合比选
    @TableField(value="coop_project_id")
    private Long coopProjectId; // 联合比选项目ID
    @TableField(value="coop_project_name")
    private String coopProjectName; // 联合比选项目名称

    @TableField(value="material_type_id")
    private Long materialTypeId; // 材料类型Id
    @TableField(value="material_type_name")
    private String materialTypeName; // 材料类型名称

    @TableField(value="submit_deadline")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date submitDeadline; // 填报截止日期
    @TableField(value="compare_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date compareTime; // 比选时间

    @TableField(value="setting_id")
    private Long settingId; // 引用的设置类型Id
    @TableField(value="tender_id")
    private Long tenderId; // 云筑招标Id
    @TableField(value="tender_no")
    private String tenderNo; // 云筑招标编号
    @TableField(value="tender_name")
    private String tenderName; // 云筑招标名称

    @TableField(value="product_type")
    private String productType; // 商品清单类型
    @TableField(value="quote_type")
    private Integer quoteType; // 报价方式
    @TableField(value="compare_status")
    private Integer compareStatus; // 比价状态，0-正常，1-中标，2-流标
    @TableField(value="notification")
    private String notification; // 通知内容
    @TableField(value="create_name")
    private String createName; // 申请人

    @TableField(exist = false)
    @SubEntity(serviceName = "compareSupplierService",pidName = "compareId")
    private List<CompareSupplierEntity> compareSupplierEntities = new ArrayList<>(); // 通知物资清单实体
    @TableField(exist = false)
    @SubEntity(serviceName = "compareSupplierTenderService",pidName = "compareId")
    private List<CompareSupplierTenderEntity> compareSupplierTenderEntities = new ArrayList<>(); // 中标供应商信息



    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getNoticeId() {
        return noticeId;
    }

    public void setNoticeId(Long noticeId) {
        this.noticeId = noticeId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectSourceId() {
        return projectSourceId;
    }

    public void setProjectSourceId(String projectSourceId) {
        this.projectSourceId = projectSourceId;
    }
    public Long getCropId() {
        return cropId;
    }

    public void setCropId(Long cropId) {
        this.cropId = cropId;
    }
    public String getCropName() {
        return cropName;
    }

    public void setCropName(String cropName) {
        this.cropName = cropName;
    }
    public String getCropSourceId() {
        return cropSourceId;
    }

    public void setCropSourceId(String cropSourceId) {
        this.cropSourceId = cropSourceId;
    }
    public Long getRealCorpId() {
        return realCorpId;
    }

    public void setRealCorpId(Long realCorpId) {
        this.realCorpId = realCorpId;
    }
    public String getRealNcCorp() {
        return realNcCorp;
    }

    public void setRealNcCorp(String realNcCorp) {
        this.realNcCorp = realNcCorp;
    }
    public String getRealCorpName() {
        return realCorpName;
    }

    public void setRealCorpName(String realCorpName) {
        this.realCorpName = realCorpName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgSourceId() {
        return orgSourceId;
    }

    public void setOrgSourceId(String orgSourceId) {
        this.orgSourceId = orgSourceId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getWjLinkman() {
        return wjLinkman;
    }

    public void setWjLinkman(String wjLinkman) {
        this.wjLinkman = wjLinkman;
    }

    public String getWjLinkphone() {
        return wjLinkphone;
    }

    public void setWjLinkphone(String wjLinkphone) {
        this.wjLinkphone = wjLinkphone;
    }

    public Integer getIsCooperation() {
        return isCooperation;
    }

    public void setIsCooperation(Integer isCooperation) {
        this.isCooperation = isCooperation;
    }

    public Long getCoopProjectId() {
        return coopProjectId;
    }

    public void setCoopProjectId(Long coopProjectId) {
        this.coopProjectId = coopProjectId;
    }

    public String getCoopProjectName() {
        return coopProjectName;
    }

    public void setCoopProjectName(String coopProjectName) {
        this.coopProjectName = coopProjectName;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Date getSubmitDeadline() {
        return submitDeadline;
    }

    public void setSubmitDeadline(Date submitDeadline) {
        this.submitDeadline = submitDeadline;
    }
    public Date getCompareTime() {
        return compareTime;
    }

    public void setCompareTime(Date compareTime) {
        this.compareTime = compareTime;
    }
    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }
    public Long getTenderId() {
        return tenderId;
    }

    public void setTenderId(Long tenderId) {
        this.tenderId = tenderId;
    }
    public String getTenderNo() {
        return tenderNo;
    }

    public void setTenderNo(String tenderNo) {
        this.tenderNo = tenderNo;
    }
    public String getTenderName() {
        return tenderName;
    }

    public void setTenderName(String tenderName) {
        this.tenderName = tenderName;
    }
    public String getProductType() {
        return productType;
    }

    public void setProductType(String productType) {
        this.productType = productType;
    }
    public Integer getQuoteType() {
        return quoteType;
    }

    public void setQuoteType(Integer quoteType) {
        this.quoteType = quoteType;
    }
    public Integer getCompareStatus() {
        return compareStatus;
    }

    public void setCompareStatus(Integer compareStatus) {
        this.compareStatus = compareStatus;
    }
    public String getNotification() {
        return notification;
    }

    public void setNotification(String notification) {
        this.notification = notification;
    }
    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public List<CompareSupplierEntity> getCompareSupplierEntities() {
        return compareSupplierEntities;
    }

    public void setCompareSupplierEntities(List<CompareSupplierEntity> compareSupplierEntities) {
        this.compareSupplierEntities = compareSupplierEntities;
    }

    public List<CompareSupplierTenderEntity> getCompareSupplierTenderEntities() {
        return compareSupplierTenderEntities;
    }

    public void setCompareSupplierTenderEntities(List<CompareSupplierTenderEntity> compareSupplierTenderEntities) {
        this.compareSupplierTenderEntities = compareSupplierTenderEntities;
    }
}
